# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import json
import os
# Create your views here.
from collections import OrderedDict

from django.core.paginator import Paginator
from django.http import HttpResponse, Http404
from django.shortcuts import render, render_to_response

from GeoInt_SIDT.tasks import add
from catalog.models import Purchase
from GeoInt_SIDT.tasks import *

# -------------------------------------------------------------------------------

########### lee archivo de configuración ################
dirname = os.path.dirname(__file__)
configfile = os.path.join(dirname, '../config/config.json')

with open(configfile, 'r') as f:
    config = json.load(f)

USERS_PATH = config['PATHS']['PATH_USERS']


###########################################################


def report_L2ASCL(request, report, purchase_id):

    # image_path =USERS_PATH + request.user.email+"/"+purchase_id+"/"+"out/T15QZD/TCI/"
    image_path = request.user.email + "/" + purchase_id + "/" + "out/T15QZD/TCI/"
    absolute_path = USERS_PATH + request.user.email + "/" + purchase_id + "/out"

    folders = os.listdir(path=absolute_path)
    with open(USERS_PATH + request.user.email + "/" + purchase_id + "/" + report + ".json") as f:
        json_data = OrderedDict(json.load(f))
        graphData = dict()
        graphData['type'] = "line"

        data = dict()
        data['labels'] = [k for k, v in sorted(json_data.items())]
        #		data['click']="chartOnClick"
        data['datasets'] = list()
        labels = set()
        for d in json_data:
            labels |= set(json_data[d].keys())
        labels.remove('date')

        labelNames = [
            "No Data", "Saturated", "Shadows", "Cloud Shadows", "Vegetation",
            "Not-Vegetated", "Whater", "Unclassified", "Cloud Medium Probablilty",
            "Cloud Hight Probablilty", "Thin Cirrus", "Snow"
        ]

        colors = [
            "#383838", "#de3d3d", "#696767", "#98775b", "#44ba5d", "#fff98b",
            "#659acc", "#ababab", "#dddddd", "#d9f9ff", "#99d4d9", "#ff8afa"
        ]

        for l in labels:
            item = dict()
            item['label'] = labelNames[int(l)]

            # item['fill'] = "false"
            if l == "0":
                item['hidden'] = "true"
            item['data'] = [v[l] * 60 * 60 / 1000000. if (l in v) else 0 for k, v in sorted(json_data.items())]
            item['backgroundColor'] = colors[int(l)]
            data['datasets'].append(item)

        data['datasets'].sort(key=lambda k: max(k['data']))

        graphData['data'] = data
        label  =  graphData['data']['labels'][0]
        defaultLabel = graphData['data']['labels'][0]
        defaultDataset = label[0:4]+"/"+label[4:6]+"/"+label[6:]
        #defaultDataset = graphData['data']['datasets'][0]['label']
        # print(settings.BASE_URL)
        #		graphData['options']['responsive']=True
        #		graphData['options']['maintainAspectRatio']=False
        # print(json.dumps(graphData).encode("utf-8")) 

    return render(request, 'L2ASCL_data.html', {"graphData": json.dumps(graphData), "report_name": "SCL Image Classification Data(Km²)", "IMAGE_PATH": image_path, 'dafaultLabel': defaultLabel, 'defaultDataSet': defaultDataset, "folders" : folders })


    # -------------------------------------------------------------------------------def Reports(request):


def Reports(request):
    progress = 0
    productList = []
    size = 0
    product_list = Purchase.objects.values('id', 'productList', 'aggreg_date', 'search__clouds', 'search__startDate',
                                           'search__endDate', 'search__process_id__name').filter(
        user_id=request.user.id, purchased=1)
    for producto in product_list:
        log_info = USERS_PATH + request.user.email + "/" + str(producto['id']) + "/L2ASCL_AreaProcessing.log"

        #####################################################
        #                progress bar                       #
        #####################################################
        if os.stat(log_info).st_size == 0:
            progress = 0
        else:
            if 'Linking Products...' in open(log_info).read():
                progress = 20
            if 'Merging Images...' in open(log_info).read():
                progress = 40
            if 'Deleting Images...' in open(log_info).read():
                progress = 50
            if 'Extracting SCL information...' in open(log_info).read():
                progress = 60
            if 'Finalizing...' in open(log_info).read():
                progress = 100

        with open(log_info, 'r') as myfile:
            log = myfile.read().replace('\n', '')

        for p in json.loads(producto['productList']):
            size = size + float(p['info']['size'][:-3])
            if size > 1000:
                size2 = size / 1000
                final_size = str(round(size2, 2)) + " GB"
            else:
                final_size = str(round(size, 2)) + " MB"

        absolute_path = USERS_PATH + request.user.email + "/" +str(producto['id'])+ "/out"
        folders = os.listdir(path=absolute_path)
        for folder in folders:
            initial_folder=folder

        productList.append({
            "process": producto['search__process_id__name'],
            "purchase_date": producto['aggreg_date'],
            "startDate": producto['search__startDate'],
            "endDate": producto['search__endDate'],
            "clouds": producto['search__clouds'],
            "size": final_size,
            "purchase_id": producto['id'],
            "progress": progress,
            "log_info": log,
            "initial_folder" :initial_folder,
        })
        size = 0
        final_size = 0
        log_info = ""
        progress = 0
        initial_folder = ""



    ##############################################
    #                paginacion                  #
    ##############################################
    #paginator = Paginator(productList, 3)  # Show 25 contacts per page
    #page = request.GET.get('page')
    #productList = paginator.get_page(page)

    return render(request, 'Reports.html', {"productList": productList})


# ------------------------------------------------------------------------
def wsProcessProgress(request):
    if request.is_ajax():
        progress = 0
        productList2 = []
        product_list = Purchase.objects.values('id', 'productList', 'aggreg_date', 'search__clouds',
                                               'search__startDate', 'search__endDate',
                                               'search__process_id__name', 'progress').filter(user_id=request.user.id, purchased=1)
        for producto in product_list:
            log_info = USERS_PATH + request.user.email + "/" + str(producto['id']) + "/L2ASCL_AreaProcessing.log"

            #####################################################
            #                progress bar                       #
            #####################################################
            if os.stat(log_info).st_size == 0:
                progress = 0
            else:
                if 'Linking Products...' in open(log_info).read():
                    progress = 20
                if 'Merging Images...' in open(log_info).read():
                    progress = 40
                if 'Deleting Images...' in open(log_info).read():
                    progress = 50
                if 'Extracting SCL information...' in open(log_info).read():
                    progress = 60
                if 'Finalizing...' in open(log_info).read():
                    progress = 100


            productList2.append({
                "purchase_id": producto['id'],
                "progress": progress,
            })

            progress = 0
            log_info = ""

        # productList2 = []
        # product_list = Purchase.objects.values('id', 'progress').filter(user_id=request.user.id, purchased=1)
        # for producto in product_list:
        #     productList2.append({
        #         "purchase_id": producto['id'],
        #         "progress": producto['progress'],
        #     })
        return HttpResponse(json.dumps(productList2))
    else:
        raise Http404


# ------------------------------------------------------------------------
# def tareas():
#     result = add.apply_async((2, 1), countdown=3)
#     result.get()
#     return render_to_response('reports_table.html', {"result": result.get()})
